==> jc-1.4.0.tar.gz: ppg/lex/LexTest.h <==
// public class ppg.lex.LexTest

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ec462b427a9d8274 ppg_lex_LexTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_lex_LexTest_H_
#define _JC_ppg_lex_LexTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_lex_LexTest$sub_refs	_jc_ppg_lex_LexTest$sub_refs;
typedef struct _jc_ppg_lex_LexTest$sub_nonrefs	_jc_ppg_lex_LexTest$sub_nonrefs;
typedef struct _jc_ppg_lex_LexTest$refs	_jc_ppg_lex_LexTest$refs;
typedef struct _jc_ppg_lex_LexTest$nonrefs	_jc_ppg_lex_LexTest$nonrefs;
typedef struct _jc_ppg_lex_LexTest$object	_jc_ppg_lex_LexTest$object;

typedef struct _jc_ppg_lex_LexTest$fields_struct	_jc_ppg_lex_LexTest$fields_struct;
typedef const struct _jc_ppg_lex_LexTest$vmethods	_jc_ppg_lex_LexTest$vmethods;
typedef const struct _jc_ppg_lex_LexTest$vtable	_jc_ppg_lex_LexTest$vtable;
typedef const struct _jc_ppg_lex_LexTest$vtype	_jc_ppg_lex_LexTest$vtype;

// Class fields structure
struct _jc_ppg_lex_LexTest$fields_struct {
	struct _jc_java_lang_String$object	*HEADER;
};
extern _jc_ppg_lex_LexTest$fields_struct _jc_ppg_lex_LexTest$class_fields;

// Constructors
extern void _jc_ppg_lex_LexTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_lex_LexTest$object *);

// Static methods
extern void _jc_ppg_lex_LexTest$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_ppg_lex_LexTest$vmethods {
};

// Vtable
struct _jc_ppg_lex_LexTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_lex_LexTest$vmethods	ppg_lex_LexTest;
};

// Vtype
struct _jc_ppg_lex_LexTest$vtype {
	_jc_type			type;
	_jc_ppg_lex_LexTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_lex_LexTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_lex_LexTest$refs {
    _jc_ppg_lex_LexTest$sub_refs	ppg_lex_LexTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_lex_LexTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_lex_LexTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_lex_LexTest$sub_nonrefs	ppg_lex_LexTest;
};

// Object instance structure
struct _jc_ppg_lex_LexTest$object {
	_jc_ppg_lex_LexTest$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_lex_LexTest$vtype	*vtype;
	_jc_ppg_lex_LexTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_lex_LexTest$vtype _jc_ppg_lex_LexTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_lex_LexTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_lex_LexTest$class_object;

#endif	/* _JC_ppg_lex_LexTest_H_ */

==> jc-1.4.6.tar.gz: ppg/lex/LexTest.h <==
// public class ppg.lex.LexTest

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ec462b427a9d8274 ppg_lex_LexTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_lex_LexTest_H_
#define _JC_ppg_lex_LexTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_lex_LexTest$sub_refs	_jc_ppg_lex_LexTest$sub_refs;
typedef struct _jc_ppg_lex_LexTest$sub_nonrefs	_jc_ppg_lex_LexTest$sub_nonrefs;
typedef struct _jc_ppg_lex_LexTest$refs	_jc_ppg_lex_LexTest$refs;
typedef struct _jc_ppg_lex_LexTest$nonrefs	_jc_ppg_lex_LexTest$nonrefs;
typedef struct _jc_ppg_lex_LexTest$object	_jc_ppg_lex_LexTest$object;

typedef struct _jc_ppg_lex_LexTest$fields_struct	_jc_ppg_lex_LexTest$fields_struct;
typedef const struct _jc_ppg_lex_LexTest$vmethods	_jc_ppg_lex_LexTest$vmethods;
typedef const struct _jc_ppg_lex_LexTest$vtable	_jc_ppg_lex_LexTest$vtable;
typedef const struct _jc_ppg_lex_LexTest$vtype	_jc_ppg_lex_LexTest$vtype;

// Class fields structure
struct _jc_ppg_lex_LexTest$fields_struct {
	struct _jc_java_lang_String$object	*HEADER;
};
extern _jc_ppg_lex_LexTest$fields_struct _jc_ppg_lex_LexTest$class_fields;

// Constructors
extern void _jc_ppg_lex_LexTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_lex_LexTest$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_ppg_lex_LexTest$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_ppg_lex_LexTest$vmethods {
};

// Vtable
struct _jc_ppg_lex_LexTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_lex_LexTest$vmethods	ppg_lex_LexTest;
};

// Vtype
struct _jc_ppg_lex_LexTest$vtype {
	_jc_type			type;
	_jc_ppg_lex_LexTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_lex_LexTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_lex_LexTest$refs {
    _jc_ppg_lex_LexTest$sub_refs	ppg_lex_LexTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_lex_LexTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_lex_LexTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_lex_LexTest$sub_nonrefs	ppg_lex_LexTest;
};

// Object instance structure
struct _jc_ppg_lex_LexTest$object {
	_jc_ppg_lex_LexTest$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_lex_LexTest$vtype	*vtype;
	_jc_ppg_lex_LexTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_lex_LexTest$vtype _jc_ppg_lex_LexTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_lex_LexTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_lex_LexTest$class_object;

#endif	/* _JC_ppg_lex_LexTest_H_ */
